@@ -19,6 +19,7 @@
 
 #include "bomb.h"
 #include "arena.h"
+#include "granatier_random.h"
 
 #include <QTimer>
 
@@ -140,7 +141,7 @@ void Bomb::updateMove()
     {
         bool bOnCenter = false;
         int xDirection = 0;
-        int xDeltaCenter = Granatier::CellSize/2 - (m_x - currentCol * Granatier::CellSize);
+        int xDeltaCenter = static_cast<int>(Granatier::CellSize/2 - (m_x - currentCol * Granatier::CellSize));
         bool bMoveAwayFromCenter = false;
         bool bIsHurdleCurrentCell = false;
         bool bIsHurdleNextCell = false;
@@ -154,7 +155,7 @@ void Bomb::updateMove()
             xDirection = -1;
         }
         int yDirection = 0;
-        int yDeltaCenter = Granatier::CellSize/2 - (m_y - currentRow * Granatier::CellSize);
+        int yDeltaCenter = static_cast<int>(Granatier::CellSize/2 - (m_y - currentRow * Granatier::CellSize));
         if (m_ySpeed > 0)
         {
             yDirection = 1;
@@ -548,8 +549,8 @@ void Bomb::updateMortarState()
 
             do
             {
-                nRow = m_arena->getNbRows() * (qrand()/1.0)/RAND_MAX;
-                nCol = m_arena->getNbColumns() * (qrand()/1.0)/RAND_MAX;
+                nRow = granatier::RNG::fromRange(0, m_arena->getNbRows()-1);
+                nCol = granatier::RNG::fromRange(0, m_arena->getNbColumns()-1);
                 if(m_arena->getCell(nRow, nCol).getType() != Granatier::Cell::WALL)
                 {
                     bFound = true;
